let debounceTimer;

const numDocInput = document.getElementById('num_doc');
const tipoDocuInput = document.getElementById('tipo_docu');
const razonSocialInput = document.getElementById('razon_social');
const direccionInput = document.getElementById('direccion');
const departamentoInput = document.getElementById('departamento');
const provinciaInput = document.getElementById('provincia');
const distritoInput = document.getElementById('distrito');
const ubigeoInput = document.getElementById('ubigeo');

// Deshabilita los campos
function deshabilitarCampos() {
    razonSocialInput.value = '';
    direccionInput.value = '';
    departamentoInput.value = '';
    provinciaInput.value = '';
    distritoInput.value = '';
    ubigeoInput.value = '';

    razonSocialInput.setAttribute('readonly', 'readonly');
    direccionInput.setAttribute('readonly', 'readonly');
    departamentoInput.setAttribute('readonly', 'readonly');
    provinciaInput.setAttribute('readonly', 'readonly');
    distritoInput.setAttribute('readonly', 'readonly');
    ubigeoInput.setAttribute('readonly', 'readonly');
}

// Habilita los campos
function habilitarCamposSiVacios() {
    if (!razonSocialInput.value.trim()) {
        razonSocialInput.removeAttribute('readonly');
    }
    
    // Eliminar el guión "-" si está presente
    direccionInput.value = direccionInput.value.trim() === '-' ? '' : direccionInput.value.trim();
    if (direccionInput.value.trim() === '') {
        direccionInput.removeAttribute('readonly');
    }

/*     // Repite este proceso para los otros campos
    departamentoInput.value = departamentoInput.value.trim() === '-' ? '' : departamentoInput.value.trim();
    if (departamentoInput.value.trim() === '') {
        departamentoInput.removeAttribute('readonly');
    }

    provinciaInput.value = provinciaInput.value.trim() === '-' ? '' : provinciaInput.value.trim();
    if (provinciaInput.value.trim() === '') {
        provinciaInput.removeAttribute('readonly');
    }

    distritoInput.value = distritoInput.value.trim() === '-' ? '' : distritoInput.value.trim();
    if (distritoInput.value.trim() === '') {
        distritoInput.removeAttribute('readonly');
    }

    ubigeoInput.value = ubigeoInput.value.trim() === '-' ? '' : ubigeoInput.value.trim();
    if (ubigeoInput.value.trim() === '') {
        ubigeoInput.removeAttribute('readonly');
    } */
}

numDocInput.addEventListener('input', function () {
    clearTimeout(debounceTimer);
    const numDoc = this.value.trim();

    if (numDoc.length === 0) {
        deshabilitarCampos();
        tipoDocuInput.value = ''; // Deja el campo tipo_docu vacío si no se ingresa ningún número de documento
        return;
    }
    
    if (numDoc.length === 8) {
        tipoDocuInput.value = '2'; // Asigna "2" si la longitud es 8
    } else if (numDoc.length >= 11) {
        tipoDocuInput.value = '4'; // Asigna "4" si la longitud es mayor o igual a 11
    } else {
        tipoDocuInput.value = ''; // Deja vacío si no cumple ninguna de las condiciones
    }

    if (numDoc.length >= 8) {
        debounceTimer = setTimeout(function () {
            fetch(`/verificar-proveedor?num_doc=${numDoc}`)
                .then(response => response.json())
                .then(data => {
                    if (data.registrado) {
                        razonSocialInput.value = data.datoProveedor;
                        direccionInput.value = data.direccion;
                        departamentoInput.value = data.departamento;
                        provinciaInput.value = data.provincia;
                        distritoInput.value = data.distrito;
                        ubigeoInput.value = data.ubigeo;
                        habilitarCamposSiVacios();
                    } else {
                        if (numDoc.length >= 11) {
                            fetch(`/consultar-ruc?num_doc=${numDoc}`)
                                .then(response => response.json())
                                .then(data => {
                                    if (data.razonSocial) {
                                        razonSocialInput.value = data.razonSocial;
                                        direccionInput.value = data.direccion;
                                        departamentoInput.value = data.departamento;
                                        provinciaInput.value = data.provincia;
                                        distritoInput.value = data.distrito;
                                        ubigeoInput.value = data.ubigeo;
                                        habilitarCamposSiVacios();
                                    } else {
                                        alert('No se encontró una persona para el RUC ingresado');
                                        habilitarCamposSiVacios();
                                    }
                                })
                                .catch(error => console.error('Error:', error));
                        } else {
                            fetch(`/consultar-dni?num_doc=${numDoc}`)
                                .then(response => response.json())
                                .then(data => {
                                    if (data.numeroDocumento) {
                                        const nombresCompletos = [data.nombres, data.apellidoPaterno, data.apellidoMaterno]
                                            .filter(Boolean)
                                            .join(' ');

                                        razonSocialInput.value = nombresCompletos;
                                        habilitarCamposSiVacios();
                                    } else {
                                        alert('No se encontró una persona para el DNI ingresado');
                                        habilitarCamposSiVacios();
                                    }
                                })
                                .catch(error => console.error('Error:', error));
                        }
                    }
                })
                .catch(error => console.error('Error:', error));
        }, 500);
    }
    if (numDoc.length >= 3 && numDoc.length <= 7) {
        debounceTimer = setTimeout(function () {
            fetch(`/verificar-proveedor?num_doc=${numDoc}`)
                .then(response => response.json())
                .then(data => {
                    if (data.registrado) {
                        razonSocialInput.value = data.datoProveedor;
                        direccionInput.value = data.direccion;
                        departamentoInput.value = data.departamento;
                        provinciaInput.value = data.provincia;
                        distritoInput.value = data.distrito;
                        ubigeoInput.value = data.ubigeo;
                        habilitarCamposSiVacios();
                    } else {
                        if (numDoc.length >= 11) {
                            fetch(`/consultar-ruc?num_doc=${numDoc}`)
                                .then(response => response.json())
                                .then(data => {
                                    if (data.razonSocial) {
                                        razonSocialInput.value = data.razonSocial;
                                        direccionInput.value = data.direccion;
                                        departamentoInput.value = data.departamento;
                                        provinciaInput.value = data.provincia;
                                        distritoInput.value = data.distrito;
                                        ubigeoInput.value = data.ubigeo;
                                        habilitarCamposSiVacios();
                                    } else {
                                        alert('No se encontró al proveedor para el RUC ingresado');
                                        habilitarCamposSiVacios();
                                    }
                                })
                                .catch(error => console.error('Error:', error));
                        } else {
                            fetch(`/consultar-dni?num_doc=${numDoc}`)
                                .then(response => response.json())
                                .then(data => {
                                    if (data.numeroDocumento) {
                                        const nombresCompletos = [data.nombres, data.apellidoPaterno, data.apellidoMaterno]
                                            .filter(Boolean)
                                            .join(' ');

                                        razonSocialInput.value = nombresCompletos;
                                        habilitarCamposSiVacios();
                                    } else {
                                        alert('No se encontró al proveedor con el DNI o COD PP ingresado');
                                        habilitarCamposSiVacios();
                                    }
                                })
                                .catch(error => console.error('Error:', error));
                        }
                    }
                })
                .catch(error => console.error('Error:', error));
        }, 500);
    } else {
        deshabilitarCampos();
    }
});
